package de.ullisroboterseite.ursanalogclock;

import java.lang.reflect.*;


/**
 * Speichert einen Wert.
 * Es wird nachgehalten, ob ein gültiger Wert vorliegt.
 */
public class PropertyBackup<E> {
   E value = null;
   boolean isValid = false;

   /**
    * Initialisiert eine neue Instanz der PropertyBackup-Klasse mit dem angegebeben Wert.
    * @param value
    */
   public PropertyBackup(E value) {
      this.value = value;
   }

   /**
    * Legt den Wert der Instanz fest.
    * @param value Der festzulegende Wert.
    */
   public void setValue(E value) {
      this.value = value;
      isValid = true;
   }

   /**
    * Ruft den aktuell gepeicherten Wert ab.
    * @return Der aktuell gepeicherte Wert
    */
   public E getValue() {
      return value;
   }

   /**
    * Ruft, wenn gültig, den gespeicherten Wert ab, ansonsten den übergebenen Vorschlagswert.
    * Wenn kein gültiger Wert vorliegt, wird der Vorschalgswert übernommen.
    * @param defaultValue Der Vorschalgswert.
    * @return  Der gespeicherte Wert oder der übergebene Vorschlagswert
    */
   public E getAndReplaceValue(E defaultValue) {
      if (isValid)
         return value;
      else {
         setValue(defaultValue);
         return defaultValue;
      }
   }
}